Welcome to PyEDDL's documentation!
==================================

PyEDDL is a Python wrapper for `EDDL
<https://github.com/deephealthproject/eddl>`_, the European Distributed Deep
Learning library.

The source code for PyEDDL is available on the `GitHub repo
<https://github.com/deephealthproject/pyeddl>`_.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   getting_started
   api/index


Indices and tables
==================

* :ref:`genindex`
